<template>
  <a-card :bordered="false">

    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form layout="inline" @keyup.enter.native="searchQuery">
        <a-row :gutter="24">
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <a-form-item label="设备编号">
              <a-input placeholder="请输入设备编号" v-model="queryParam.equipmentId"/>
            </a-form-item>
          </a-col>
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <a-form-item label="单据状态">
              <a-select placeholder="请选择单据状态" v-model="queryParam.reportStatus" allow-clear>
                <a-select-option v-for="item in report_repair_status_list" :key="item.value">{{ item.label }}
                </a-select-option>
              </a-select>
            </a-form-item>
          </a-col>
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <a-form-item label="故障简称">
              <!--              <a-select placeholder="请选择故障简称" v-model="queryParam.faultName" allow-clear>-->
              <!--                <a-select-option v-for="item in faultReasonList" :key="item.faultName">-->
              <!--                  {{ item.faultName }}-->
              <!--                </a-select-option>-->
              <!--              </a-select>-->
              <a-input placeholder="请输入故障简称" v-model="queryParam.faultName" allow-clear/>
            </a-form-item>
          </a-col>
          <!--            <a-col :xl="6" :lg="7" :md="8" :sm="24">-->
          <!--              <a-form-item label="故障分类">-->
          <!--                <a-input placeholder="请输入故障分类" v-model="queryParam.faultType"></a-input>-->
          <!--              </a-form-item>-->
          <!--            </a-col>-->
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <a-form-item label="故障时间">
              <a-range-picker showTime v-model="faultTimeRange" value-format="YYYY-MM-DD HH:mm:ss"
                              @change="handleTimeRangeChange"
                              style="width: 100%"/>
            </a-form-item>
          </a-col>
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <a-form-item label="是否停机">
              <a-radio-group v-model="queryParam.breakdownFlag">
                <a-radio v-for="item in breakdown_flag_list" :value="item.value">{{ item.label }}</a-radio>
              </a-radio-group>
            </a-form-item>
          </a-col>
          <template v-if="toggleSearchStatus">

          </template>
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <span style="float: left;overflow: hidden;" class="table-page-search-submitButtons">
              <a-button type="primary" @click="searchQuery" icon="search">查询</a-button>
              <a-button @click="searchReset" icon="reload" style="margin-left: 8px">重置</a-button>
              <!--              <a @click="handleToggleSearch" style="margin-left: 8px">-->
              <!--                {{ toggleSearchStatus ? '收起' : '展开' }}-->
              <!--                <a-icon :type="toggleSearchStatus ? 'up' : 'down'"/>-->
              <!--              </a>-->
            </span>
          </a-col>

        </a-row>
      </a-form>
    </div>

    <!-- 操作按钮区域 -->
    <div class="table-operator">
      <a-button @click="handleAdd" type="primary" icon="plus">新增</a-button>
      <a-button type="primary" icon="download" @click="handleExportXls('故障报修')">导出</a-button>
      <a-upload name="file" :showUploadList="false" :multiple="false" :headers="tokenHeader" :action="importExcelUrl"
                @change="handleImportExcel">
        <a-button type="primary" icon="import">导入</a-button>
      </a-upload>
      <a-dropdown v-if="selectedRowKeys.length > 0">
        <a-menu slot="overlay">
          <a-menu-item key="1" @click="batchDel">
            <a-icon type="delete"/>
            作废
          </a-menu-item>
        </a-menu>
        <a-button style="margin-left: 8px"> 批量操作
          <a-icon type="down"/>
        </a-button>
      </a-dropdown>
    </div>

    <!-- table区域-begin -->
    <div>
      <div class="ant-alert ant-alert-info" style="margin-bottom: 16px;">
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择 <a
        style="font-weight: 600">{{ selectedRowKeys.length }}</a>项
        <a style="margin-left: 24px" @click="onClearSelected">清空</a>
      </div>

      <a-table
        ref="table"
        size="middle"
        bordered
        rowKey="id"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        class="j-table-force-nowrap"
        :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}"
        @change="handleTableChange">

        <template slot="imageFiles" slot-scope="text, record" v-if="text">
          <a @click="handlePreviewImages(record)">预览</a>
        </template>

        <span slot="action" slot-scope="text, record" v-if="record.reportStatus=='WAIT_REPAIR'">
          <a @click="handleEdit(record)">编辑</a>

          <a-divider type="vertical"/>

          <a-popconfirm title="确定作废吗?" @confirm="() => handleDelete(record.id)">
            <a>作废</a>
          </a-popconfirm>
          <!--          <a-dropdown>-->
          <!--            <a class="ant-dropdown-link">更多 <a-icon type="down"/></a>-->
          <!--            <a-menu slot="overlay">-->
          <!--              <a-menu-item>-->
          <!--                <a-popconfirm title="确定删除吗?" @confirm="() => handleDelete(record.id)">-->
          <!--                  <a>删除</a>-->
          <!--                </a-popconfirm>-->
          <!--              </a-menu-item>-->
          <!--            </a-menu>-->
          <!--          </a-dropdown>-->
        </span>

      </a-table>
    </div>
    <!-- table区域-end -->

    <!-- 表单区域 -->
    <eamReportRepair-modal ref="modalForm" :breakdownFlagList="breakdown_flag_list" :faultReasonList="faultReasonList"
                           @ok="modalFormOk"/>
    <!-- 图片预览弹窗 -->
    <images-preview-modal ref="imagesPreviewModalRef" :imageListUrl="currentImageListUrl"/>
  </a-card>
</template>

<script>
import '@/assets/less/TableExpand.less'
import EamReportRepairModal from './modules/EamReportRepairModal'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import LxSearchEquipmentSelect from '@views/eam/equipment/modules/LxSearchEquipmentSelect.vue'
import { ajaxGetDictItems, getDictItemsFromCache } from '@/api/api'
import ImagesPreviewModal from '@views/eam/repair/modules/ImagesPreviewModal.vue'
import { getAction } from '@/api/manage'


export default {
  name: 'EamReportRepairList',
  mixins: [JeecgListMixin],
  components: {
    ImagesPreviewModal,
    LxSearchEquipmentSelect,
    EamReportRepairModal
  },
  data() {
    return {
      description: '故障报修管理页面',
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        {
          title: '设备编号',
          align: 'center',
          dataIndex: 'equipmentId_dictText',
          width: 200
        },
        {
          title: '状态',
          align: 'center',
          dataIndex: 'reportStatus_dictText',
          width: 100
        },
        {
          title: '故障简称',
          align: 'center',
          dataIndex: 'faultName',
          width: 100
        },
        {
          title: '故障分类',
          align: 'center',
          dataIndex: 'faultType_dictText',
          width: 100
        },
        {
          title: '故障描述',
          align: 'center',
          dataIndex: 'faultDescription',
          width: 200
        },
        {
          title: '故障开始时间',
          align: 'center',
          dataIndex: 'faultStartTime',
          width: 200
        },
        {
          title: '是否停机',
          align: 'center',
          dataIndex: 'breakdownFlag_dictText',
          width: 100
        },
        {
          title: '报修图片',
          align: 'center',
          dataIndex: 'imageFiles',
          scopedSlots: { customRender: 'imageFiles' },
          width: 100
        },
        {
          title: '备注',
          align: 'center',
          dataIndex: 'remark'
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          scopedSlots: { customRender: 'action' },
          width: 150
        }
      ],
      breakdown_flag_list: [],
      report_repair_status_list: [],
      faultTimeRange: [],
      faultReasonList: [],
      currentImageListUrl: '',
      url: {
        list: '/eam/eamReportRepair/list',
        delete: '/eam/eamReportRepair/abolish',
        deleteBatch: '/eam/eamReportRepair/abolishBatch',
        exportXlsUrl: 'eam/eamReportRepair/exportXls',
        importExcelUrl: 'eam/eamReportRepair/importExcel',
        faultReasonList: '/eam/equipmentFaultReason/list'
      }
    }
  },
  computed: {
    importExcelUrl: function() {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`
    }
  },
  created() {
    this.initDictData('breakdown_flag')
    this.initDictData('report_repair_status')
    this.getFaultReasonListByApi()
  },
  methods: {
    /**
     * 获取数据字典值
     * @param dictCode 数据字典对应记录编码
     */
    initDictData(dictCode) {
      // //优先从缓存中读取字典配置
      if (getDictItemsFromCache(dictCode)) {
        this[dictCode + '_list'] = getDictItemsFromCache(dictCode)
        return
      }
      //根据字典Code, 初始化字典数组
      ajaxGetDictItems(dictCode, null).then((res) => {
        if (res.success) {
          this[dictCode + '_list'] = res.result
          return
        }
      })
    },

    // 调用接口获取故障原因列表
    getFaultReasonListByApi() {
      const that = this
      getAction(this.url.faultReasonList)
        .then(res => {
          console.log('res', res)
          that.faultReasonList = res.result.records
        })
    },

    /**
     * 故障时间选择器变化时触发
     * @param valueArray
     */
    handleTimeRangeChange(valueArray) {
      this.queryParam.startTime = valueArray[0]
      this.queryParam.endTime = valueArray[1]
    },

    /**
     * 预览图片
     * @param imageFiles 表格行图片地址
     */
    handlePreviewImages({ imageFiles }) {
      this.currentImageListUrl = imageFiles
      this.$refs.imagesPreviewModalRef.visible = true
    },

    searchReset() {
      this.queryParam = {}
      this.faultTimeRange = []
      this.loadData(1)
    }
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>